''' digital.py '''

from machine import Pin
    
def write(pin, state):
    write = Pin(pin, Pin.OUT)
    if state == 1:
        write.on()
    elif state == 0:
        write.off()
    #print(pin," is writing", state)  

def on(pin):
    print(pin," is on\n")
    on = Pin(pin, Pin.OUT)
    on.on()
   
def off(pin):
    print(pin," is off\n")
    off = Pin(pin, Pin.OUT)
    off.off()
     
def read(pin):
    value = Pin(pin, Pin.IN)
    print(pin, " returns value ", value())
    return(value())    



'''robot.py'''

from machine import Pin, I2C

i2c = I2C(1, scl=Pin(15), sda=Pin(14), freq=400_000)

def transmit(address, mode, index, pwm, direction):         
    checkSum = address + mode + index + pwm + direction
    mylist=[address, mode, index, pwm, direction, checkSum]
    motor = bytearray(mylist)
    i2c.writeto(0x40,motor)

def moveForward(speed):
    transmit(0x40, 1, 1, speed, 1)
    transmit(0x40, 1, 0, speed, 1)
    
def moveBackward(speed):
    transmit(0x40, 1, 1, speed, 0)
    transmit(0x40, 1, 0, speed, 0)
    
def turnRight(speed):
    transmit(0x40, 1, 1, speed, 1)
    transmit(0x40, 1, 0, speed, 0)
    
def turnLeft(speed):
    transmit(0x40, 1, 1, speed, 0)
    transmit(0x40, 1, 0, speed, 1)
    
def stop():
    transmit(0x40, 1, 1, 0, 0)
    transmit(0x40, 1, 0, 0, 1)



''' pwm.py '''

from machine import Pin, PWM
from time import sleep

D9 = PWM(Pin(9))
D10 = PWM(Pin(10))
D11 = PWM(Pin(11))

D9.freq(1000)
D10.freq(1000)
D11.freq(1000)

def write(pin, duty):
    if pin == 9:
        D9.duty_u16(duty)
    elif pin == 10:
        D10.duty_u16(duty)
    elif pin == 11:
        D11.duty_u16(duty)



import setuptools

with open('README.md', 'r', encoding='utf-8') as f:
    long_description = f.read()

repo = 'https://github.com/ziap/mke'

setuptools.setup(
    name='mkeio',
    author='Bùi Huy Giáp',
    author_email='67962871+ziap@users.noreply.github.com',
    description='MKE PyPI (Python Package Index)',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url=repo,
    project_urls={
        'Documentation': repo + '#readme',
        'Bug Reports': repo + '/issues',
        'Source Code': repo
        },
    package_dir={'': 'src'},
    packages=setuptools.find_packages(where='src'),
    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Education',
        
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
       
        'Programming Language :: Python :: Implementation :: MicroPython',
        
        'Natural Language :: Vietnamese',
        
        'Operating System :: OS Independent',
        ],
    python_requires='>=3.6'
    )



''' analog.py '''

from machine import Pin, ADC            #importing Pin and ADC class
voltage_offset = 3.3

def set_voltage(voltage):
    voltage_offset = voltage
    print(voltage_offset)

def read(pin):
    analogPin = ADC(pin)
    analogValue = analogPin.read_u16()
    print("analog value at pin ", pin, " is ", analogValue)
    return analogValue

def map_range(x, in_min, in_max, out_min, out_max):
    return (x - in_min) * (out_max - out_min) // (in_max - in_min) + out_min

def read_percent(pin):
    analogPin = ADC(pin)
    analogValue = map_range(analogPin.read_u16(), 0, 65536, 0, 100)
    print("analog value at pin ", pin, " is ", analogValue)
    return analogValue

def read_voltage(pin):
    analogPin = ADC(pin)
    analogValue = map_range(analogPin.read_u16(), 0, 65536, 0, 3.30)
    print("analog value at pin ", pin, " is ", analogValue)
    return analogValue
